==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/prop/UpgradedHealthItem.java <==
package cc.thonly.reverie_dreams.item.prop;

import cc.thonly.reverie_dreams.interfaces.ILivingEntity;
import cc.thonly.reverie_dreams.sound.SoundEventInit;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1324;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_3218;
import net.minecraft.class_3468;
import net.minecraft.class_5134;

public class UpgradedHealthItem extends class_1792 {
    public UpgradedHealthItem(class_1793 settings) {
        super(settings);
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        if (!world.field_9236 && world instanceof class_3218 serverWorld) {
            class_1799 itemStack = user.method_5998(hand);
            world.method_43128(null, user.method_23317(), user.method_23320(), user.method_23321(), SoundEventInit.UP, user.method_5634(), 1.0f, 1.0f);
            ILivingEntity modifier = (ILivingEntity) user;
            float value = modifier.getMaxHealthModifier();
            modifier.setMaxHealthModifier(value + 2);
            class_1324 maxHealthAttributeInstance = user.method_5996(class_5134.field_23716);
            if (maxHealthAttributeInstance != null) {
                maxHealthAttributeInstance.method_6192(user.method_6063() + 2);
            }
            user.method_7259(class_3468.field_15372.method_14956(this));
            itemStack.method_57008(1, user);
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }
}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/prop/UpgradedHealthItem.java <==
package cc.thonly.reverie_dreams.item.prop;

import cc.thonly.reverie_dreams.config.ReverieDreamsConfiguration;
import cc.thonly.reverie_dreams.inf.ILivingEntity;
import cc.thonly.reverie_dreams.sound.SoundEventInit;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1324;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2561;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3468;
import net.minecraft.class_5134;

public class UpgradedHealthItem extends class_1792 {
    public UpgradedHealthItem(class_1793 settings) {
        super(settings);
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        if (!world.field_9236 && world instanceof class_3218 serverWorld && user instanceof class_3222 player) {
            class_1799 itemStack = user.method_5998(hand);
            class_1324 maxHealthAttributeInstance = user.method_5996(class_5134.field_23716);
            if (maxHealthAttributeInstance != null && maxHealthAttributeInstance.method_6194() + 2 > ReverieDreamsConfiguration.MAX_UPGRADED_HEALTH_VALUE) {
                player.method_43502(class_2561.method_43469("item.action.click.upgraded_health.max_full", ReverieDreamsConfiguration.MAX_UPGRADED_HEALTH_VALUE), true);
                return class_1269.field_52422;
            }

            world.method_43128(null, user.method_23317(), user.method_23320(), user.method_23321(), SoundEventInit.UP, user.method_5634(), 1.0f, 1.0f);
            ILivingEntity modifier = (ILivingEntity) user;
            float value = modifier.getMaxHealthModifier();
            modifier.setMaxHealthModifier(value + 2);
            if (maxHealthAttributeInstance != null) {
                maxHealthAttributeInstance.method_6192(user.method_6063() + 2);
            }
            user.method_7259(class_3468.field_15372.method_14956(this));
            itemStack.method_57008(1, user);
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }
}
